pub struct Conveyor {
pub needs_update: bool,
pub bundles: Vec<Option<Bundle>>,
/* private fields */
}Fields
needs_update: boolbundles: Vec<Option<Bundle>>Implementations
Sourceimpl Conveyor
impl Conveyor
pub fn new() -> Conveyor
Sourcepub fn upsert_gadget(&mut self, device: &Device, desc: &GadgetDescriptor<'_>)
pub fn upsert_gadget(&mut self, device: &Device, desc: &GadgetDescriptor<'_>)
Updates or inserts a gadget and marks self as requiring an update
pub fn update_gadget( &mut self, queue: &Queue, gadget_label: &str, data: &[u8], ) -> Result<(), ConveyorError>
pub fn update_bundles(&mut self, device: &Device)
pub fn attach_bundles(&self, render_pass: &mut RenderPass<'_>)
Sourcepub fn collect_bind_group_layouts(
bundles_collection: Vec<&Vec<Option<Bundle>>>,
) -> Vec<Option<&BindGroupLayout>>
pub fn collect_bind_group_layouts( bundles_collection: Vec<&Vec<Option<Bundle>>>, ) -> Vec<Option<&BindGroupLayout>>
Collects bind group layouts from a collection of bundles.
Behavior
- If no bundle defines a bind group at index
n, but a later indexm > nis defined, the result at positionnwill beNone. - If multiple bundles define a bind group at the same index, only the first encountered (in iteration order) will be used.
- The output length equals the maximum bundle length across the collection.